#ifndef __WRRCU100API_H__
#define __WRRCU100API_H__

#include <windows.h>

#ifdef __cplusplus
extern "C" {
#endif

#define WRRCU100_CLASS_ID_DEVICE_LIST   0x00000001
#define WRRCU100_CLASS_ID_DEVICE        0x00000002

#pragma pack(push,1)

typedef struct
{
    char    SerialNumber[9];
    LONG    Id;
} WRRCU100_DEVICE_INFO;

#pragma pack(pop)


#undef INTERFACE
#define INTERFACE IWRRCU100DeviceList

DECLARE_INTERFACE(IWRRCU100DeviceList)
{
    STDMETHOD_(UINT32,GetCount)(THIS) PURE;
    STDMETHOD_(BOOL,BeginEnumeration)(THIS) PURE;
    STDMETHOD_(BOOL,Next)(THIS_ WRRCU100_DEVICE_INFO *DeviceInfo) PURE;
    STDMETHOD_(BOOL,EndEnumeration)(THIS);
    STDMETHOD_(VOID,Release)(THIS) PURE;
};

struct IWRRCU100;
typedef struct IWRRCU100 *LPWRRCU100;

#define WRRCU100_STATE_DISCONNECTED                 0x00000001
#define WRRCU100_STATE_HIGH_TEMPERATURE             0x00000002
#define WRRCU100_STATE_LOW_VOLTAGE                  0x00000004
#define WRRCU100_STATE_OVERLOAD_AZ                  0x00000008
#define WRRCU100_STATE_OVERLOAD_EL                  0x00000010
#define WRRCU100_STATE_AZ_IS_NOT_MOVING             0x00000020
#define WRRCU100_STATE_EL_IS_NOT_MOVING             0x00000040
#define WRRCU100_STATE_MECHANICAL_RANGES_UNKNOWN    0x00000080
#define WRRCU100_STATE_CALIBRATION_REQUIRED         0x00000100
#define WRRCU100_STATE_CALIBRATION_IN_PROGRESS      0x00000200

#define WRRCU100_LED_GREEN_ON_FLASH_RED_ON          0x00000000
#define WRRCU100_LED_GREEN_ON_RED_ON                0x00000001
#define WRRCU100_LED_GREEN_OFF_RED_ON               0x00000002
#define WRRCU100_LED_GREEN_ON_RED_OFF               0x00000003
#define WRRCU100_LED_GREEN_OFF_RED_OFF              0x00000004
 

#undef INTERFACE
#define INTERFACE IWRRCU100Notification

DECLARE_INTERFACE(IWRRCU100Notification)
{
    STDMETHOD_(VOID,PositionChanged)(THIS_ LPWRRCU100 Device,INT32 Azimuth,INT32 Elevation) PURE;   
    STDMETHOD_(VOID,StateChanged)(THIS_ LPWRRCU100 Device,UINT32 State) PURE;
};

#undef INTERFACE
#define INTERFACE IWRRCU100

DECLARE_INTERFACE(IWRRCU100)
{
    STDMETHOD_(BOOL,Open)(THIS_ LONG Id) PURE;
    STDMETHOD_(BOOL,Close)(THIS) PURE;    
    STDMETHOD_(BOOL,IsOpen)(THIS) PURE;
    
    STDMETHOD_(BOOL,GetFirmwareVersion)(THIS_ char *Buffer,UINT32 BufferSize) PURE;
    STDMETHOD_(BOOL,GetSerialNumber)(THIS_ char *Buffer,UINT32 BufferSize) PURE;
    
    STDMETHOD_(BOOL,GetState)(THIS_ UINT32 *State) PURE;
        
    STDMETHOD_(BOOL,GetPosition)(THIS_ INT32 *Azimuth,INT32 *Elevation) PURE;
    STDMETHOD_(BOOL,SetPosition)(THIS_ INT32 Azimuth,INT32 Elevation) PURE;
    
    STDMETHOD_(BOOL,Stop)(THIS) PURE;

    STDMETHOD_(BOOL,SetOffsets)(THIS_ INT32 AzimuthOffset,INT32 ElevationOffset) PURE;
    STDMETHOD_(BOOL,GetOffsets)(THIS_ INT32 *AzimuthOffset,INT32 *ElevationOffset) PURE;
    
    STDMETHOD_(BOOL,GetAzimuthOffsetRange)(THIS_ INT32 *MinOffset,INT32 *MaxOffset) PURE;       
    STDMETHOD_(BOOL,GetElevationOffsetRange)(THIS_ INT32 *MinOffset,INT32 *MaxOffset) PURE;

    STDMETHOD_(BOOL,GetAzimuthRange)(THIS_ INT32 *MinAzimuth,INT32 *MaxAzimuth) PURE;
    STDMETHOD_(BOOL,GetElevationRange)(THIS_ INT32 *MinElevation,INT32 *MaxElevation) PURE;
    
    STDMETHOD_(BOOL,StartCalibration)(THIS_ BOOL ForceToDetermineMechanicalRanges) PURE;
    STDMETHOD_(VOID,StopCalibration)(THIS) PURE;
    
    STDMETHOD_(BOOL,SetLED)(THIS_ UINT32 LED) PURE;
    STDMETHOD_(BOOL,GetLED)(THIS_ UINT32 *LED) PURE;
    
    STDMETHOD_(BOOL,RegisterNotification)(THIS_ IWRRCU100Notification *Notification) PURE;
    STDMETHOD_(BOOL,UnregisterNotification)(THIS_ IWRRCU100Notification *Notification) PURE;
    
    STDMETHOD_(VOID,Release)(THIS) PURE;
};


typedef BOOL (__stdcall *CREATE_INSTANCE)(UINT32 ClassId,void **Intf);

#ifdef __cplusplus
};
#endif


#endif
 